#include <R.h>

void matrix_print(char *name, double *a, int *m, int *n, int *lda, int *level);

void F77_NAME(matpr) (char *name, double *a, int *m, int *n, int *lda, int *level);

